#!/usr/local/bin/perl
#############################################
# ILP_test.pl - A test suite for ILP.pm
#
# Tests;
# a) Connect and log in. Display the ILP version and timeout
# b) Get the lists the test user is subscribed to
# c) Get and temporarily change the user's MAIL setting for a list
# d) Display the name and creation date for all lists for which
#        the user can REVIEW
##############################################


#--------------------------------------------
# Configuration - Change these settings to those of a subscriber
#       within your local ListProc installation

my $host = $ARGV[0] || &input('Host? ') or die "Need a host name!\n";;
my $user = $ARGV[1] || &input('Subscriber Address? ')  or die "Need a subscriber address!\n";
my $pass = $ARGV[2] || &input('Subscriber Password? ')  or die "Need a password!\n";

# These options will also work for tests 1 and 4
# my $user = '';                       # the subscriber address
# my $pass = '';                       # the corresponding password for a list
# my $host = 'localhost';              # the machine hosting ILP



#-------- End of Local Configuration --------

use ILP 0.06;

#-------- Test 1 ------------
print "Beginning test #1...\n";

$ilp = new ILP( $host, $user, $pass ) or die $ILP::ERRMSG;

print "\tConnection? Successful.";

print "\n\tLogin? ";
print (($ilp->login_type !~ /^casual|\?/)
	? "Successful -- login type = " . $ilp->login_type
	: "*** failed. Logged in as a casual user");

print "\n\tListProc Version? ";
print ($ilp->lp_version || "***failed! version not obtained");

print "\n\tSession Timeout ? ";
print ($ilp->timeout
	? $ilp->timeout / 60 . " minutes"
	: "***failed!");

print "\n";

#-------- Test 2 ------------
print "\nBeginning test #2...\n";

my @user_subs = $ilp->get_list_subs;
print "\tSubscriptions for user $user:\n";

print ( scalar(@user_subs)
	? "\t\t" . join("\n\t\t", @user_subs)
	: "\t\t*** None found!" );

print "\n";

#-------- Test 3 ------------
print "\nBeginning test #3...\n";

# use one of the lists from test #2, if any
if ( !scalar(@user_subs)) {
	print "\tCan't do--user is not subscribed to anything\n";
}
else {
	my $tmp_list = $user_subs[0];
	my $old_setting = $ilp->get_user_options($tmp_list, 'mail');
	if (! $old_setting) {
		print "\tCouldn't get current MAIL setting for $ilp->user " .
		    " on list $tmp_list(Error was $ILP::ERRMSG)\n";
	}
	else {
		my $new_setting = lc($old_setting) eq 'postpone'
		    ? 'digest' : 'postpone';
		print "\tChanging setting from $old_setting to $new_setting for " .
		    $ilp->user . " on list $tmp_list... ";

		my ($code) = $ilp->set_mail($tmp_list, $new_setting);
		if ($code != 100) {
			print "Failed--aborting test\n";
		}
		else {
			print "Succeeded\n";
			print "\tNow changing it back... ";
			($code) = $ilp->set_mail($tmp_list, $old_setting);
			if ($code != 100) {
				print "Failed!\n"
			}
			else {
				print "Succeeded!\n"
			}
		}
	}
}


#-------- Test 4 ------------
print "\nBeginning test #4...\n";

my @user_avail = $ilp->get_list_avail_names;
if (! scalar(@user_avail)) {
	print "\tNo lists are available for REVIEW!\n";
	$ILP::ERRMSG and print "\t(Error was: $ILP::ERRMSG\n";
}
else {
	foreach $tmp_list ( @user_avail ) {
		print "\t$tmp_list Created\t";
		print $ilp->get_list_options($tmp_list, 'created')
			|| "<REVIEW failed>";
		print "\n";
	}
}



$ilp->close;
exit 0;


sub input {
	my ($text) = @_;
	print STDOUT $text;
	$_ = <STDIN>;
	chomp $_;
	$_
}

__END__

Sample output:

Beginning test #1...
    Connection? Successful.
    Login? Successful -- login type = subscriber
    ListProc Version? 7.2
    Session Timeout ? 30 minutes

Beginning test #2...
    Subscriptions for user chad.redman@yale.edu:
        YTEST-L
        TEST2-LIST

Beginning test #3...
    Changing setting from POSTPONE to digest for chad.redman@yale.edu on list
YTEST-L... Succeeded
    Now changing it back... Succeeded!


Beginning test #4...
    ytest-l@credman.development.yale.edu: Created? Thu Apr 24 12:11:05 1997
    test2-list@credman.development.yale.edu: Created? Wed Aug 12 15:12:54 1998
