#!/usr/local/bin/perl

# Syntax:
# <command>
#     Return the available lists and their descriptions.
#     The lists are given one per line, with the name
#     and description separated by tabs
# <command> -d delimiter
#     List the listname/description pair separated by
#     a user-defined delimiter
# <command> -html TABLE
#     Create an HTML table from the values
# <command> -html UL
#     Create an HTML unordered list
# <command> -html SELECT
#     Create an HTML <SELECT> form field


use ILP 0.06;

use Getopt::Long;
%opt = ();
GetOptions( \%opt, 'd=s', 'html=s' );


my $host = $ARGV[0] || &input('Host? ') or die "Cancelling...\n";
my $listmaster = $ARGV[1] || &input('Site Admin Name? ')  or die "Cancelling...\n";
my $sitepass = $ARGV[2] || &input('Admin Password? ')  or die "Cancelling...\n";



$ilp = ILP->new( $host, $listmaster, $sitepass)
	or die( "ILP connection failed: <$ILP::ERRMSG>" );


($ilp->login_type() eq 'manager') or die "Error--not logged in as manager\n";

@avail = ($ilp->get_list_avail('local'));

my %avail=();

foreach (@avail) {
	(/\s+/);
	my ($list, $desc) = ($`, $');
	$list =~ s/\@.*//;
	$list = uc($list);
	$avail{$list} = $desc ? $desc : $list;
}

	($opt{'html'} eq 'TABLE') and print "<TABLE>\n";
	($opt{'html'} eq 'UL') and print "<UL>\n";
	($opt{'html'} eq 'SELECT') and print qq(<FORM ACTION="xxx">\n<SELECT NAME="xxxxx" SIZE="10" MULTIPLE>\n);


foreach (sort byvalue keys %avail) {
	print &format($_, $avail{$_}), "\n";
}

	($opt{'html'} eq 'TABLE') and print "</TABLE>\n";
	($opt{'html'} eq 'UL') and print "</UL>\n";
	($opt{'html'} eq 'SELECT') and print "</SELECT>\n</FORM>\n";


exit 0;

sub byvalue { lc($avail{$a}) cmp lc($avail{$b}) }

sub format {
	my $a = shift;
	my $b = shift;
	if ($opt{'d'}) {
		return $a . $opt{'d'} . $b
	}
	elsif ($opt{'html'}) {
		($opt{'html'} eq 'TABLE') and return "\t<TR><TD>$a</TD><TD>$b</TD></TR>";
		($opt{'html'} eq 'UL') and return "    <LI><DT>$a\n        <DD><I>$b</I>";
		($opt{'html'} eq 'SELECT') and return qq^\t<OPTION VALUE="$a">$b ($a)^;
	}

	return "$a\t$b"
}

sub input {
	my ($text) = @_;
	print STDOUT $text;
	$_ = <STDIN>;
	chomp $_;
	$_
}


__END__


