#!/usr/local/bin/perl
### ilp_client.pl - An ILP client
#
# Syntax: ilp_client.pl <host> <name> <password>
#
# This functions as a simple interface to the Interactive ListProc
# server (ILP). Basically it emulates the unix ilp client, except
# that this is platform independent. It even works for Windows NT,
# which is nice if you enable the command history and QuickEdit modes
# (See hint below for use).
#
# This program uses the ILP.pm module, which must be present somewhere
# in the @INC path. Note that 'use' directives are interpreted before
# other commands; to modify @INC on-the-fly, try:
#     BEGIN { push(@INC, 'path-to-ilp-directory') }
#
#
# Hints for use on Windows
# ------------------------
# This program has been tested on Windows 95 and Windows NT, using
# ActiveState Perl version 5.00502. I run this as a shortcut to a console
# program, as:
#   %windir%\System32\cmd.exe /c "perl ilp_client.pl myhost myaddress"
# where myaddress is my owner's address I have for most of the lists on the
# target host. The password is not specified, and instead I will be prompted
# for it. The host and address can also be left out of the command line.
# The perl executable is somewhere in my PATH variable.
#
# Note that this really bites in MS-DOS. NT's console is much slicker.
#
########################################################################
# The latest version of this software can be found in:
#     http://pantheon.yale.edu/~cer28/projects/ilp/
#
# Copyright (C) 1999 Chad Redman, Yale University
#
# Last Modified: 1998/05/19
########################################################################

use ILP 0.06;

### definitions

my $host = $ARGV[0] || &input('Host? ') or exit 0;
my $name = $ARGV[1] || &input('Owner Name? ')  or exit 0;
my $pass = $ARGV[2] || &input('Password? ')  or exit 0;

my $prompt = 'request: ';

$ilp = ILP->new("$host:372", $name, $pass)  or  do_error( $ILP::ERRMSG, $ilp );

print "Logged in as: ", $ilp->{login_type}, "\n";

while (1) {

	$cmd = &input( $prompt );
	# Command aliases
	$cmd =~ s/^subgrep (\w+) /RUN ADMIN-L $1 subgrep /; # my personal hack

	#print "<<$cmd\n";   # uncomment if you want command confirmation

	last if ( uc($cmd) eq 'QUIT' );
	$cmd and ($code, $resp) = $ilp->do_command( $cmd );
	$cmd and print "$resp\n";
}

$ilp->close();

exit 0;


##############################################

sub do_error {
	my ($msg, $ilp) = @_;
	print "Error!\n";
	print "$msg\n";
	$ilp and $ilp->close();
	exit 1;
}

sub input {
	my ($text) = @_;
	print STDOUT $text;
	$_ = <STDIN>;
	chomp $_;
	$_
}


__END__


